//
//  The BUTTON CLASS
//
// Although Javascript does not support private members, you shouldn't
// access any of the member variables.  Instead, you should use the
// methods provided.
//
// getTitle() will return the correct title or label
// getLink() will return the correct url for this button
// getImage() will return the correct image for this button
// isSeparator() will return true if this button is actually a Separator
//               (The Yahoo Companion feed doesn't distinguish between button
//                and separator.)
// isSearchToggle() will return true if this button is the special Search
//                Toggle button.  (The little magnifying glass.)
//

function Button(title,raw)
{
    this.raw = raw;
    this.title = title;
    this.toolTip = null;
    this.type = "";
    this.img = "";
    this.link = "";
    this.parse(this.raw);
}

// getTitle will return the proper title for a button.

Button.prototype.getTitle = function()
{
    // the Logo has no title
    if(this.type == "logo")
        return null;
    
    if(this.isSearchToggle())
        return "";
    return this.title;
}

Button.prototype.getTooltip = function()
{    
    return this.toolTip || this.title;
}

Button.prototype.getImage = function()
{
        return this.img;
}

Button.prototype.getLink = function()
{
    return this.link;
}

Button.prototype.isSeparator = function()
{
    if(this.type == "vsep")
        return true;
    else
        return false;
}

Button.prototype.isSearchToggle = function()
{
	return (this.type == "stoggle");
}

// parse takes a string which must contain the button data encoded.
// This should only be called to construct a button.
Button.prototype.parse = function(txt)
{
    var end = txt.indexOf('\x18');
    this.type = txt.substr(0, end);
    this.link = this.extractLink(txt.substr(end+1));
    
    // if buttonType has a .bmp in it, then it is actually an image.
    // need to find those images on the yimg servers...
    // if the buttonType is empty, and the title is "Sign On", the use title
    
    this.img = this.type;
}

Button.prototype.extractLink = function(txt)
{
    var link = "";
    // we need to skip ahead 3 ^As
    var buffer = /\x01.*?\x01.*?\x01%?(.*?)\x18/.exec(txt);
    if (buffer) {
    	link = buffer[1];
	if (buffer = /at=%(.*?)[\x18\x19]/.exec(txt))
            this.toolTip = buffer[1];
    }
    // Now adjust for a leading $ESRV
    link = link.replace(/^\$ESRV\x01%/,"http://edit.companion.yahoo.com");
    return link;
}

